Clazz.declarePackage("J.shapebio");
Clazz.load(["J.shapebio.BioShapeCollection"], "J.shapebio.Strands", null, function(){
var c$ = Clazz.decorateAsClass(function(){
this.isMesh = false;
Clazz.instantialize(this, arguments);}, J.shapebio, "Strands", J.shapebio.BioShapeCollection);
});
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
